summaryrefslogtreecommitdiffstats
path: root/krdc/kremoteview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /krdc/kremoteview.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'krdc/kremoteview.h')
-rw-r--r--krdc/kremoteview.h35
1 files changed, 18 insertions, 17 deletions
diff --git a/krdc/kremoteview.h b/krdc/kremoteview.h
index 09b312c0..6aa68151 100644
--- a/krdc/kremoteview.h
+++ b/krdc/kremoteview.h
@@ -24,10 +24,10 @@
#include "events.h"
typedef enum {
- QUALITY_UNKNOWN=0,
- QUALITY_HIGH=1,
- QUALITY_MEDIUM=2,
- QUALITY_LOW=3
+ TQUALITY_UNKNOWN=0,
+ TQUALITY_HIGH=1,
+ TQUALITY_MEDIUM=2,
+ TQUALITY_LOW=3
} Quality;
/**
@@ -61,11 +61,12 @@ enum DotCursorState {
* MotionNotify events will be forwarded.
*
*/
-class KRemoteView : public QWidget
+class KRemoteView : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- KRemoteView(TQWidget *parent = 0,
+ KRemoteView(TQWidget *tqparent = 0,
const char *name = 0,
WFlags f = 0);
@@ -135,7 +136,7 @@ public:
* The backend must also emit a @ref changeSize()
* when the size of the framebuffer becomes available
* for the first time or the size changed.
- * @return the remote framebuffer size, a null QSize
+ * @return the remote framebuffer size, a null TQSize
* if unknown
*/
virtual TQSize framebufferSize() = 0;
@@ -151,7 +152,7 @@ public:
* Checks whether the view is currently quitting.
* @return true if it is quitting
* @see startQuitting()
- * @see setStatus()
+ * @see settqStatus()
*/
virtual bool isQuitting() = 0;
@@ -172,7 +173,7 @@ public:
* dialogs to the user) and start connecting. Should not block
* without running the event loop (so displaying a dialog is ok).
* When the view starts connecting the application must call
* @ref setStatus() with the status REMOTE_VIEW_CONNECTING.
* @return true if successful (so far), false
* otherwise
* @see connected()
@@ -185,9 +186,9 @@ public:
/**
* Returns the current status of the connection.
* @return the status of the connection
- * @see setStatus()
+ * @see settqStatus()
*/
- enum RemoteViewStatus status();
+ enum RemoteViewtqStatus status();
public slots:
/**
@@ -252,7 +253,7 @@ signals:
* Emitted when the status of the view changed.
* @param s the new status
*/
- void statusChanged(RemoteViewStatus s);
+ void statusChanged(RemoteViewtqStatus s);
/**
* Emitted when the password dialog is shown or hidden.
@@ -265,7 +266,7 @@ signals:
* Emitted when the mouse on the remote side has been moved.
* @param x the new x coordinate
* @param y the new y coordinate
- * @param buttonMask the mask of mouse buttons (bit 0 for first mouse
+ * @param buttonMask the tqmask of mouse buttons (bit 0 for first mouse
* button, 1 for second button etc)a
*/
void mouseStateChanged(int x, int y, int buttonMask);
@@ -274,21 +275,21 @@ protected:
/**
* The status of the remote view.
*/
- enum RemoteViewStatus m_status;
+ enum RemoteViewtqStatus m_status;
/**
* Set the status of the connection.
* Emits a statusChanged() signal.
* Note that the states need to be set in a certain order,
* see @ref RemoteViewStatus. setStatus() will try to do this
* transition automatically, so if you are in REMOTE_VIEW_CONNECTING
* and call setStatus(REMOTE_VIEW_PREPARING), setStatus() will
* emit a REMOTE_VIEW_AUTHENTICATING and then REMOTE_VIEW_PREPARING.
* If you transition backwards, it will emit a
* REMOTE_VIEW_DISCONNECTED before doing the transition.
* @param s the new status
*/
- virtual void setStatus(RemoteViewStatus s);
+ virtual void settqStatus(RemoteViewtqStatus s);
};
#endif
@@ -172,7 +173,7 @@ public:
* without running the event loop (so displaying a dialog is ok).
* When the view starts connecting the application must call
- * @ref setStatus() with the status REMOTE_VIEW_CONNECTING.
+ * @ref settqStatus() with the status REMOTE_VIEW_CONNECTING.
* @return true if successful (so far), false
* otherwise
@@ -274,21 +275,21 @@ protected:
* Emits a statusChanged() signal.
* Note that the states need to be set in a certain order,
- * see @ref RemoteViewStatus. setStatus() will try to do this
+ * see @ref RemoteViewtqStatus. settqStatus() will try to do this
* transition automatically, so if you are in REMOTE_VIEW_CONNECTING
@@ -274,21 +275,21 @@ protected:
* transition automatically, so if you are in REMOTE_VIEW_CONNECTING
- * and call setStatus(REMOTE_VIEW_PREPARING), setStatus() will
+ * and call settqStatus(REMOTE_VIEW_PREPARING), settqStatus() will
* emit a REMOTE_VIEW_AUTHENTICATING and then REMOTE_VIEW_PREPARING.
* If you transition backwards, it will emit a